"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.clearLine = clearLine;
exports.color = color;
exports.configure = configure;
exports.error = error;
exports.log = log;
exports.progress = progress;
exports.verbose = verbose;
exports.warn = warn;
var _nodeReadline = _interopRequireDefault(require("node:readline"));
var _chalk = _interopRequireDefault(require("chalk"));
var _colors = require("./colors");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const defaultConfig = {
  verbose: false,
  silent: false
};
let config = {
  ...defaultConfig
};
const colorError = _chalk.default.hex(_colors.colors.error);
const colorWarn = _chalk.default.hex(_colors.colors.warn);
const colorVerbose = _chalk.default.hex(_colors.colors.verbose);
function configure(options) {
  config = {
    ...config,
    ...options
  };
}

// Jest is wrapping console.* calls, so we need to get the raw console object
const rawConsole = require('console');
function error() {
  rawConsole.error(colorError(...arguments));
}
function warn() {
  if (config.silent) return;
  rawConsole.warn(colorWarn(...arguments));
}
function log() {
  if (config.silent) return;
  rawConsole.log(...arguments);
}
function verbose() {
  if (!config.verbose || config.silent) return;
  rawConsole.log(colorVerbose(...arguments));
}
function color(color) {
  if (config.silent) return;
  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }
  return rawConsole.log(_chalk.default.hex(_colors.colors[color])(args));
}

/** Log message that indicates progress of operation, does not output the trailing newline. */
function progress(message) {
  process.stdout.write(message);
}

/**
 * Clears current lint. To be used in conjunction with `progress`.
 */
function clearLine() {
  _nodeReadline.default.clearLine(process.stdout, 0);
  _nodeReadline.default.cursorTo(process.stdout, 0);
}
//# sourceMappingURL=logger.js.map