import readline from 'node:readline';
import chalk from 'chalk';
import { colors } from './colors';
const defaultConfig = {
  verbose: false,
  silent: false
};
let config = {
  ...defaultConfig
};
const colorError = chalk.hex(colors.error);
const colorWarn = chalk.hex(colors.warn);
const colorVerbose = chalk.hex(colors.verbose);
export function configure(options) {
  config = {
    ...config,
    ...options
  };
}

// Jest is wrapping console.* calls, so we need to get the raw console object
const rawConsole = require('console');
export function error() {
  rawConsole.error(colorError(...arguments));
}
export function warn() {
  if (config.silent) return;
  rawConsole.warn(colorWarn(...arguments));
}
export function log() {
  if (config.silent) return;
  rawConsole.log(...arguments);
}
export function verbose() {
  if (!config.verbose || config.silent) return;
  rawConsole.log(colorVerbose(...arguments));
}
export function color(color) {
  if (config.silent) return;
  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }
  return rawConsole.log(chalk.hex(colors[color])(args));
}

/** Log message that indicates progress of operation, does not output the trailing newline. */
export function progress(message) {
  process.stdout.write(message);
}

/**
 * Clears current lint. To be used in conjunction with `progress`.
 */
export function clearLine() {
  readline.clearLine(process.stdout, 0);
  readline.cursorTo(process.stdout, 0);
}
//# sourceMappingURL=logger.js.map